summaryrefslogtreecommitdiffstats
path: root/umbrello/umbrello/dialogs/diagramprintpage.h
diff options
context:
space:
mode:
Diffstat (limited to 'umbrello/umbrello/dialogs/diagramprintpage.h')
-rw-r--r--umbrello/umbrello/dialogs/diagramprintpage.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/umbrello/umbrello/dialogs/diagramprintpage.h b/umbrello/umbrello/dialogs/diagramprintpage.h
index 94e1deb5..b7980ca0 100644
--- a/umbrello/umbrello/dialogs/diagramprintpage.h
+++ b/umbrello/umbrello/dialogs/diagramprintpage.h
@@ -41,10 +41,10 @@ public:
/**
* Constructs the diagram print page.
*
* @param tqparent The tqparent to the page.
* @param doc The @ref UMLDoc class instance being used.
*/
- DiagramPrintPage(TQWidget * tqparent, UMLDoc *doc);
+ DiagramPrintPage(TQWidget * parent, UMLDoc *doc);
/**
* Stnadard deconstructor.
@@ -41,10 +41,10 @@ public:
* Constructs the diagram print page.
*
- * @param tqparent The tqparent to the page.
+ * @param parent The parent to the page.
* @param doc The @ref UMLDoc class instance being used.
*/